import _extends from "@babel/runtime/helpers/esm/extends";
import { parse } from 'qs';

/**
 * parse query string to object
 *
 * @param {string} query
 * @param {object} [options={}]
 * @param {boolean} [options.allowSparse] - parse sparse arrays
 * @param {boolean} [options.comma] - comma to join array
 * @param {boolean} [options.ignoreQueryPrefix=true] - avoid the leading question mark
 * @param {string} [options.delimiter] - delimiter
 */
function parseQueryString(query, options) {
  if (options === void 0) {
    options = {};
  }
  var _options = options,
    _options$allowSparse = _options.allowSparse,
    allowSparse = _options$allowSparse === void 0 ? false : _options$allowSparse,
    _options$ignoreQueryP = _options.ignoreQueryPrefix,
    ignoreQueryPrefix = _options$ignoreQueryP === void 0 ? true : _options$ignoreQueryP,
    comma = _options.comma,
    delimiter = _options.delimiter;
  var mergedOptions = _extends({
    allowSparse: allowSparse,
    ignoreQueryPrefix: ignoreQueryPrefix
  }, typeof comma !== 'undefined' && {
    comma: comma
  }, typeof delimiter !== 'undefined' && {
    delimiter: delimiter
  });
  return parse(query, mergedOptions);
}
export default parseQueryString;